package cn.com.ctop.kuaishou.modules.batch.controller;

import cn.com.ctop.common.module.entity.CtopOauthToken;
import cn.com.ctop.common.module.mapper.CtopOauthTokenMapper;
import cn.com.ctop.common.module.utils.Check;
import cn.com.ctop.kuaishou.modules.batch.entity.KuaiShouCreative;
import cn.com.ctop.kuaishou.modules.batch.service.IKuaiShouCreativeService;
import cn.com.ctop.kuaishou.modules.batch.service.IKuaiShouUpdateService;
import cn.com.ctop.kuaishou.modules.batch.service.IMaterialRefuseService;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;

@Slf4j
@RestController
@RequestMapping("/MaterialRefuse")
public class MaterialRefuseController {
    @Autowired
    private IMaterialRefuseService materialRefuseService;
    @Autowired
    private CtopOauthTokenMapper oauthTokenMapper;
    @Autowired
    private IKuaiShouUpdateService updateService;
    @Autowired
    private IKuaiShouCreativeService creativeService;


    @GetMapping(value = "/getRefuseCreative")
    public Result<IPage<KuaiShouCreative>> getRefuseCreative(KuaiShouCreative creative,
                                                             @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                             @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                             HttpServletRequest req) {
        Result<IPage<KuaiShouCreative>> result = new Result<>();
        try {

            QueryWrapper<KuaiShouCreative> queryWrapper = QueryGenerator.initQueryWrapper(creative, req.getParameterMap());
            queryWrapper.eq("status", 42);
            queryWrapper.orderByDesc("creative_create_time");
            Page<KuaiShouCreative> page = new Page<KuaiShouCreative>(pageNo, pageSize);
            IPage<KuaiShouCreative> pageList = creativeService.page(page, queryWrapper);
            result.setSuccess(true);
            result.setResult(pageList);

        } catch (Exception e) {
            result.setSuccess(false);
        }
        return result;
    }

    @PostMapping(value = "/updateCreative")
    public Map<String, Object> updateCreative(@RequestBody JSONObject jsonObject) {
        Map<String, Object> map = new HashMap<>();
        if (Check.isNull(jsonObject)) {
            map.put("code", -1);
            map.put("message", "入参为空");
            return map;
        }

        Long accountId = jsonObject.getLong("accountId");
        QueryWrapper<CtopOauthToken> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("account_id", accountId);
        queryWrapper.eq("media_id", 2);
        queryWrapper.orderByDesc("create_time");
        queryWrapper.last("limit 1");
        CtopOauthToken ctopOauthToken = oauthTokenMapper.selectOne(queryWrapper);
        if (Check.isNull(ctopOauthToken)) {
            map.put("code", -1);
            map.put("message", "未获取授权信息");
            return map;
        }

        Map<String, Object> creativeMap = updateService.updateCreative(ctopOauthToken.getAccessToken(), accountId, jsonObject);
        if (Check.isNullMap(creativeMap)) {

            map.put("code", -1);
            map.put("message", "修改失败，返回为空");
            return map;
        }

        if ((Integer) creativeMap.get("code") != 0) {
            map.put("code", -1);
            map.put("message", creativeMap.get("message"));
            return map;
        }

        return null;
    }


    @PostMapping(value = "/batchUpdateCreative")
    public Result<JSONObject> batchUpdateCreative(@RequestBody JSONObject jsonObject) {

        Result<JSONObject> result = new Result<>();
        JSONObject returnJson = new JSONObject();
        if (Check.isNull(jsonObject)) {
            result.setSuccess(false);
            result.setMessage("入参为空");
            return result;
        }

        Long accountId = jsonObject.getLong("accountId");
        QueryWrapper<CtopOauthToken> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("account_id", accountId);
        queryWrapper.eq("media_id", 2);
        queryWrapper.orderByDesc("create_time");
        queryWrapper.last("limit 1");
        CtopOauthToken ctopOauthToken = oauthTokenMapper.selectOne(queryWrapper);
        if (Check.isNull(ctopOauthToken)) {
            result.setSuccess(false);
            result.setMessage("未获取到授权信息");
            return result;
        }

        JSONArray creativeArr = jsonObject.getJSONArray("creativeArr");
        Integer successCount = 0;
        Integer failCount = 0;
        if (!Check.isNull(creativeArr)) {

            for (int i = 0; i < creativeArr.size(); i++) {
                JSONObject creativeJson = creativeArr.getJSONObject(i);
                if (!Check.isNull(creativeJson)) {
                    Long creativeId = creativeJson.getLong("creativeId");
                    JSONObject requestJson = new JSONObject();
                    requestJson.put("creativeId", creativeId);
                    String description = creativeJson.getString("description");
                    if (!Check.isNull(description)) {
                        requestJson.put("description", convertMoString(description));
                        Map<String, Object> creativeMap = updateService.updateCreative(ctopOauthToken.getAccessToken(), accountId, requestJson);
                        Integer code = (Integer) creativeMap.get("code");
                        if (code == 0) {
                            log.info("拒审重提成功,accountId:{},creativeId:{}", accountId, creativeId);
                            successCount += 1;

                        } else {
                            log.info("拒审重提失败,accountId:{},creativeId:{}", accountId, creativeId);
                            failCount += 1;
                        }
                    }

                }

            }

        }
        returnJson.put("successCount", successCount);
        returnJson.put("failCount", failCount);

        result.setSuccess(true);
        result.setResult(returnJson);
        return result;
    }


    public static synchronized String convertMoString(String sMo) {

        if (Check.isNull(sMo)) {
            return null;
        }
        String newString = null;
        try {
            if (sMo.contains("，")) {
                return sMo.replace('，', ',');
            } else if (sMo.contains("～")) {
                newString = sMo.replace('～', '~');
            } else if (sMo.contains("。")) {
                newString = sMo.replace('。', '.');
            } else if (sMo.contains("；")) {
                newString = sMo.replace('；', ';');
            } else if (sMo.contains("！")) {
                newString = sMo.replace("！", "!");

            } else if (sMo.contains("？")) {
                newString = sMo.replace('？', '?');

            } else if (sMo.contains("：")) {
                newString = sMo.replace('：', ':');

            } else if (sMo.contains("“")) {
                newString = sMo.replace('“', '＂');

            } else if (sMo.contains("”")) {
                newString = sMo.replace('”', '＂');

            } else if (sMo.contains("<")) {
                newString = sMo.replace('>', '》').replace('<', '《');
            } else if (sMo.contains(",")) {
                newString = sMo.replace(',', '，');
            } else if (sMo.contains(".")) {
                newString = sMo.replace('.', '。');
            } else if (sMo.contains(";")) {
                newString = sMo.replace(';', '；');
            } else if (sMo.contains("!")) {
                newString = sMo.replace("!", "！");

            } else if (sMo.contains("?")) {
                newString = sMo.replace('?', '？');

            } else if (sMo.contains(":")) {
                newString = sMo.replace(':', '：');

            } else if (sMo.contains("＂")) {
                newString = sMo.replace('＂', '“');

            } else if (sMo.contains("＂")) {
                newString = sMo.replace('＂', '”');
            } else if (sMo.contains("《")) {
                newString = sMo.replace('》', '>').replace('《', '<');
            } else if (sMo.contains("~")) {
                newString = sMo.replace('~', '～');
            } else {
                newString = sMo;
            }

        } catch (Exception ex) {
            return sMo;
        }
        return newString;
    }

}
